/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details.
*/
#ifndef _MESSAGE_H
#define _MESSAGE_H

#ifdef __cplusplus
extern "C" {
#endif

/* -------------------- Default Message Definition -------------------- */

#define MSG_DEVICE_ERROR                    1
#define MSG_TIME_SYNC                       2
#define MSG_DEVICE_MEMORY_INFO              3
#define MSG_SYSTEM_EXECUTE                  4	/* client to remotely execute an executable file */
#define MSG_SYSTEM_EXECUTE_OK               5

#define MSG_DEVICE_MEMORY_INFO_GET          6   /* get the memory info. immediately */
#define MSG_PROGRAM_QUIT                    9   /* send this message to the system and ask it to quit */

#define MSG_CLNTXDEV_SEARCH_GATEWAY         11	/* client/agent searches the gateway, i.e., get its location or its id */
#define MSG_GATEWAY_LOCATION                12	/* a gateway responds its location */
#define MSG_CLIENT_LOGIN_GATEWAY            14
#define MSG_DEVICE_LOGIN_GATEWAY            15
#define MSG_GATEWAY_ACCEPT_LOGIN            16
#define MSG_DEVICE_NICK                     17
#define MSG_DEVICE_LEAVE                    18
#define MSG_CLIENT_NICK                     19
#define MSG_CLIENT_LEAVE                    20
#define MSG_GATEWAY_LEAVE                   21

#define MSG_GATEWAY_DLL_NAME_GET            30
#define MSG_GATEWAY_DLL_NAME                31
#define MSG_GATEWAY_DLL_NAME_END            32

#define MSG_DEVICE_DLL_NAME_GET             33
#define MSG_DEVICE_DLL_NAME                 34
#define MSG_DEVICE_DLL_NAME_END             35

/* file transfer : status report */
#define MSG_MXFTP_ERROR_MESSAGE             50
#define MSG_MXFTP_DNLOAD_COMPLETE           51
#define MSG_MXFTP_UPLOAD_COMPLETE           52
#define MSG_MXFTP_DNLOAD_STATUS             53
#define MSG_MXFTP_UPLOAD_STATUS             54

/* file transfer : major codes */
#define MSG_MXFTP_QUIT                      60
#define MSG_MXFTP_UPLOAD_DIRECT             63
#define MSG_MXFTP_DNLOAD_LOGIN              64
#define MSG_MXFTP_UPLOAD_ACCEPT             65
#define MSG_MXFTP_DNLOAD_DATA               67
#define MSG_MXFTP_UPLOAD_DATA               68

#define MSG_MXFTP_2TIER_DEV2CGW             61	/* 2-tiers, download from device to the client/gateway */
#define MSG_MXFTP_2TIER_CGW2DEV             62	/* 2-tiers, upload to device from the client/gateway */
#define MSG_MXFTP_3TIER_GWY2CLI             71	/* 3-tiers */
#define MSG_MXFTP_3TIER_CLI2GWY             72	/* 3-tiers */
#define MSG_MXFTP_3TIER_DEV2CLI             73	/* 3-tiers */
#define MSG_MXFTP_3TIER_CLI2DEV             74	/* 3-tiers */

/* manage the configuration file */
#define MSG_CONFIG_ERROR                    90	/* */
#define MSG_CONFIG_RELOAD                   91
#define MSG_CONFIG_RELOAD_OK                92
#define MSG_CONFIG_KEY_VALUE_SET            93
#define MSG_CONFIG_KEY_VALUE_SET_OK         94
#define MSG_CONFIG_FLASH_FILE               95
#define MSG_CONFIG_FLASH_FILE_OK            96
#define MSG_CONFIG_KEY_VALUE_GET            97
#define MSG_CONFIG_KEY_VALUE                98
#define	MSG_CONFIG_KEY_VALUE_END            99


#define MSG_DEVICE_ECHO_CLIENT_DATA         995
#define MSG_GATEWAY_BROADCAST_DEVICES_CLIENTS			996	/* broadcast a message to all clients/devices */
#define MSG_GATEWAY_BROADCAST_DEVICES       997	/* broadcast a message to all devices */
#define MSG_GATEWAY_BROADCAST_CLIENTS       998	/* broadcast a message to all clients */
#define MSG_GATEWAY_BYPASS_NAMED_DATA       999

/* -------------------- fmngr.dll Message Definition -------------------- */
#define MSG_FMNGR_GATEWAY_BROWSE            120
#define MSG_FMNGR_GATEWAY_BROWSE_INFO       121
#define MSG_FMNGR_GATEWAY_BROWSE_END        122
#define MSG_FMNGR_GATEWAY_FILE_EXIST        123
#define MSG_FMNGR_GATEWAY_FILE_EXIST_INFO   124
#define MSG_FMNGR_GATEWAY_RENAME            125
#define MSG_FMNGR_GATEWAY_RENAME_OK         126
#define MSG_FMNGR_GATEWAY_MKDIR             127
#define MSG_FMNGR_GATEWAY_MKDIR_OK          128
#define MSG_FMNGR_GATEWAY_RMDIR             129
#define MSG_FMNGR_GATEWAY_RMDIR_OK          130
#define MSG_FMNGR_GATEWAY_DELETE            131
#define MSG_FMNGR_GATEWAY_DELETE_OK         132
#define MSG_FMNGR_GATEWAY_DELETE_ALL        133
#define MSG_FMNGR_GATEWAY_DELETE_ALL_OK     134
#define MSG_FMNGR_GATEWAY_CHMOD             135
#define MSG_FMNGR_GATEWAY_CHMOD_OK          136

#define MSG_FMNGR_DEVICE_BROWSE             140
#define MSG_FMNGR_DEVICE_BROWSE_INFO        141
#define MSG_FMNGR_DEVICE_BROWSE_END         142
#define MSG_FMNGR_DEVICE_FILE_EXIST         143
#define MSG_FMNGR_DEVICE_FILE_EXIST_INFO    144
#define MSG_FMNGR_DEVICE_RENAME             145
#define MSG_FMNGR_DEVICE_RENAME_OK          146
#define MSG_FMNGR_DEVICE_MKDIR              147
#define MSG_FMNGR_DEVICE_MKDIR_OK           148
#define MSG_FMNGR_DEVICE_RMDIR              149
#define MSG_FMNGR_DEVICE_RMDIR_OK           150
#define MSG_FMNGR_DEVICE_DELETE             151
#define MSG_FMNGR_DEVICE_DELETE_OK          152
#define MSG_FMNGR_DEVICE_DELETE_ALL         153
#define MSG_FMNGR_DEVICE_DELETE_ALL_OK      154
#define MSG_FMNGR_DEVICE_CHMOD              155
#define MSG_FMNGR_DEVICE_CHMOD_OK           156

/* -------------------- system.dll Message Definition -------------------- */
#define MSG_DEVICE_REBOOT                   170
#define MSG_DEVICE_REBOOT_OK                171
#define MSG_DEVICE_INFO_GET                 172
#define MSG_DEVICE_INFO                     173
#define MSG_DEVICE_STORAGE_INFO_GET         174
#define MSG_DEVICE_STORAGE_INFO             175

/* -------------------- net.dll Message Definition -------------------- */
#define MSG_NETMGR_ADAPTER_INFO_GET         180
#define MSG_NETMGR_ADAPTER_INFO             181
#define MSG_NETMGR_ADAPTER_INFO_END         182
#define MSG_NETMGR_ADAPTER_INFO_SET         183
#define MSG_NETMGR_ADAPTER_INFO_SET_OK      184
#define MSG_NETMGR_DNS_INFO_GET             185
#define MSG_NETMGR_DNS_INFO                 186
#define MSG_NETMGR_DNS_INFO_SET             187
#define MSG_NETMGR_DNS_INFO_SET_OK          188

/* -------------------- time.dll Message Definition -------------------- */
#define MSG_TIMEMGR_TIME_GET                190
#define MSG_TIMEMGR_TIME_GET_OK             191
#define MSG_TIMEMGR_TIME_SYNC               192
#define MSG_TIMEMGR_TIME_SYNC_OK            193
#if 0
#define MSG_TIMEMGR_RTC_GET                 190
#define MSG_TIMEMGR_RTC_GET_OK              191
#define MSG_TIMEMGR_RTC_SYNC_SYS            192
#define MSG_TIMEMGR_RTC_SYNC_SYS_OK         193
#define MSG_TIMEMGR_SYS_GET                 194
#define MSG_TIMEMGR_SYS_GET_OK              195
#define MSG_TIMEMGR_SYS_SET                 196
#define MSG_TIMEMGR_SYS_SET_OK              197
#endif

/* -------------------- proc.dll Message Definition -------------------- */
#define MSG_PROCMGR_PROCESS_INFO_GET        200
#define MSG_PROCMGR_PROCESS_INFO            201
#define MSG_PROCMGR_PROCESS_END             202
#define MSG_PROCMGR_PROCESS_STOP            203
#define MSG_PROCMGR_PROCESS_STOP_OK         204

/* -------------------- launch.dll Message Definition -------------------- */
#define MSG_AUTO_LAUNCH_INFO_GET            210
#define MSG_AUTO_LAUNCH_INFO                211
#define MSG_AUTO_LAUNCH_INFO_END            212
#define MSG_AUTO_LAUNCH_INFO_SET            213
#define MSG_AUTO_LAUNCH_INFO_SET_END        214
#define MSG_AUTO_LAUNCH_INFO_SET_OK         215

/* -------------------- shell.dll Message Definition -------------------- */
#define MSG_SHELL_DEVICE_EXECUTE            280
#define MSG_SHELL_DEVICE_EXECUTE_OK         281
#define MSG_SHELL_DEVICE_STOP               282
#define MSG_SHELL_DEVICE_STOP_OK            283
#define MSG_SHELL_PROGRAM_OUTPUT            284
#define MSG_SHELL_PROGRAM_OUTPUT_END	    285
#define MSG_SHELL_DEVICE_OUTPUT             286
#define MSG_SHELL_DEVICE_OUTPUT_END         287


/* -------------------- ats.dll Message Definition -------------------- */
/* ats.h: 400 ~ 499 */


/* -------------------- deploy.dll Message Definition -------------------- */
/* deploy.h: 300 ~ 399 */


/* -------------------- Customized Message Definition -------------------- */


#ifdef __cplusplus
}   
#endif

#endif /* _MESSAGE_H */
